Learn R Programming

covid19srilanka (version 1.1.0)

vaccination: Covid-19 Vaccination Counts in Sri Lanka

Description

Daily summary of the Coronavirus (COVID-19) cases by state/province.

Date

Date in YYYY-MM-DD format.

DVaccine

Name of the vaccine.

First dose

Total number of people who have received the first dose on the given date.

Second dose

Total number of people who have received the first dose on the given date.

Usage

vaccination

Arguments

Format

An object of class spec_tbl_df (inherits from tbl_df, tbl, data.frame) with 471 rows and 4 columns.